@@ -20,35 +20,39 @@ import (
 
 func TestRampingVUsConfigValidation(t *testing.T) {
 	t.Parallel()
-
-	errs := NewRampingVUsConfig("default").Validate()
-	require.NotEmpty(t, errs)
-	assert.Contains(t, errs[0].Error(), "one stage has to be specified")
-
-	c := NewRampingVUsConfig("stage")
-	c.Stages = []Stage{
-		{Target: null.IntFrom(0), Duration: types.NullDurationFrom(12 * time.Second)},
-	}
-	errs = c.Validate()
-	require.Empty(t, errs) // by default StartVUs is 1
-
-	c.StartVUs = null.IntFrom(0)
-	errs = c.Validate()
-	require.NotEmpty(t, errs)
-	assert.Contains(t, errs[0].Error(), "greater than 0")
-
 	const maxConcurrentVUs = 100_000_000
 
+	t.Run("no stages", func(t *testing.T) {
+		t.Parallel()
+		errs := NewRampingVUsConfig("default").Validate()
+		require.NotEmpty(t, errs)
+		assert.Contains(t, errs[0].Error(), "one stage has to be specified")
+	})
+	t.Run("basic 1 stage", func(t *testing.T) {
+		t.Parallel()
+		c := NewRampingVUsConfig("stage")
+		c.Stages = []Stage{
+			{Target: null.IntFrom(0), Duration: types.NullDurationFrom(12 * time.Second)},
+		}
+		errs := c.Validate()
+		require.Empty(t, errs) // by default StartVUs is 1
+
+		c.StartVUs = null.IntFrom(0)
+		errs = c.Validate()
+		require.NotEmpty(t, errs)
+		assert.Contains(t, errs[0].Error(), "greater than 0")
+	})
+
 	t.Run("If startVUs are larger than maxConcurrentVUs, the validation should return an error", func(t *testing.T) {
 		t.Parallel()
 
-		c = NewRampingVUsConfig("stage")
+		c := NewRampingVUsConfig("stage")
 		c.StartVUs = null.IntFrom(maxConcurrentVUs + 1)
 		c.Stages = []Stage{
 			{Target: null.IntFrom(0), Duration: types.NullDurationFrom(1 * time.Second)},
 		}
 
-		errs = c.Validate()
+		errs := c.Validate()
 		require.NotEmpty(t, errs)
 		assert.Contains(t, errs[0].Error(), "the startVUs exceed max limit of")
 	})
@@ -56,13 +60,13 @@ func TestRampingVUsConfigValidation(t *testing.T) {
 	t.Run("For multiple VU values larger than maxConcurrentVUs, multiple errors are returned", func(t *testing.T) {
 		t.Parallel()
 
-		c = NewRampingVUsConfig("stage")
+		c := NewRampingVUsConfig("stage")
 		c.StartVUs = null.IntFrom(maxConcurrentVUs + 1)
 		c.Stages = []Stage{
 			{Target: null.IntFrom(maxConcurrentVUs + 2), Duration: types.NullDurationFrom(1 * time.Second)},
 		}
 
-		errs = c.Validate()
+		errs := c.Validate()
 		require.Equal(t, 2, len(errs))
 		assert.Contains(t, errs[0].Error(), "the startVUs exceed max limit of")
 
@@ -72,13 +76,13 @@ func TestRampingVUsConfigValidation(t *testing.T) {
 	t.Run("VU values below maxConcurrentVUs will pass validation", func(t *testing.T) {
 		t.Parallel()
 
-		c = NewRampingVUsConfig("stage")
+		c := NewRampingVUsConfig("stage")
 		c.StartVUs = null.IntFrom(0)
 		c.Stages = []Stage{
 			{Target: null.IntFrom(maxConcurrentVUs - 1), Duration: types.NullDurationFrom(1 * time.Second)},
 		}
 
-		errs = c.Validate()
+		errs := c.Validate()
 		require.Empty(t, errs)
 	})
 }
